@@ -70,6 +70,13 @@ struct bfloat16_t
         *this = bfloat16_t(float(a));
     }
 
+    /// Constructor from std::size_t
+    __host__ __device__ __forceinline__
+    bfloat16_t(std::size_t a)
+    {
+        *this = bfloat16_t(float(a));
+    }
+
     /// Default constructor
     bfloat16_t() = default;
 
@@ -186,7 +193,7 @@ struct bfloat16_t
 
     /// numeric_traits<bfloat16_t>::max
     __host__ __device__ __forceinline__
-    static bfloat16_t max() {
+    static bfloat16_t (max)() {
         uint16_t max_word = 0x7F7F;
         return reinterpret_cast<bfloat16_t&>(max_word);
     }
